==> lclint_2.1b-1.tar.gz: lclint-2.1b/src/Headers/idDeclList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994, 1995, 1996.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. This code may not be re-distributed or modified
**        without permission from MIT (contact 
**        lclint-request@larch.lcs.mit.edu.)  
**
**        Modification and re-distribution are encouraged,
**        but we want to keep track of changes and
**        distribution sites.
*/
# ifndef idDeclLIST_H
# define idDeclLIST_H

typedef /*@only@*/ idDecl o_idDecl;

abst_typedef struct _idDeclList
{
  int nelements;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ o_idDecl  *elements;
} *idDeclList ;

/*@iter idDeclList_elements (sef idDeclList x, yield exposed idDecl el); @*/
# define idDeclList_elements(x, m_el) \
   { int m_ind; idDecl *m_elements = &((x)->elements[0]); \
     for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
       { idDecl m_el = *(m_elements++); 

# define end_idDeclList_elements }}

extern /*@only@*/ idDeclList idDeclList_singleton (/*@only@*/ idDecl e) ;
extern idDeclList idDeclList_add (/*@returned@*/ idDeclList s, /*@only@*/ idDecl el) ; 

extern /*@unused@*/ /*@only@*/ cstring idDeclList_unparse (idDeclList s) ;
extern void idDeclList_free (/*@only@*/ idDeclList s) ;

/*@constant int idDeclListBASESIZE;@*/
# define idDeclListBASESIZE SMALLBASESIZE

# else
# error "Multiple include"
# endif

==> lclint_2.4b.orig.tar.gz: lclint-2.4b/src/Headers/idDeclList.h <==
/*
** Copyright (c) Massachusetts Institute of Technology 1994-1998.
**          All Rights Reserved.
**          Unpublished rights reserved under the copyright laws of
**          the United States.
**
** THIS MATERIAL IS PROVIDED AS IS, WITH ABSOLUTELY NO WARRANTY EXPRESSED
** OR IMPLIED.  ANY USE IS AT YOUR OWN RISK.
**
** This code is distributed freely and may be used freely under the 
** following conditions:
**
**     1. This notice may not be removed or altered.
**
**     2. Works derived from this code are not distributed for
**        commercial gain without explicit permission from MIT 
**        (for permission contact lclint-request@sds.lcs.mit.edu).
*/
# ifndef idDeclLIST_H
# define idDeclLIST_H

typedef /*@only@*/ idDecl o_idDecl;

abst_typedef struct _idDeclList
{
  int nelements;
  int nspace;
  /*@reldef@*/ /*@relnull@*/ o_idDecl  *elements;
} *idDeclList ;

/*@iter idDeclList_elements (sef idDeclList x, yield exposed idDecl el); @*/
# define idDeclList_elements(x, m_el) \
   { int m_ind; idDecl *m_elements = &((x)->elements[0]); \
     for (m_ind = 0 ; m_ind < (x)->nelements; m_ind++) \
       { idDecl m_el = *(m_elements++); 

# define end_idDeclList_elements }}

extern /*@only@*/ idDeclList idDeclList_singleton (/*@only@*/ idDecl p_e) ;
extern idDeclList idDeclList_add (/*@returned@*/ idDeclList p_s, /*@only@*/ idDecl p_el) ; 

extern /*@unused@*/ /*@only@*/ cstring idDeclList_unparse (idDeclList p_s) ;
extern void idDeclList_free (/*@only@*/ idDeclList p_s) ;

/*@constant int idDeclListBASESIZE;@*/
# define idDeclListBASESIZE SMALLBASESIZE

# else
# error "Multiple include"
# endif
